# SPDX-FileCopyrightText: 2018 Brent Rubell for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`ttn_usa`
======================================================
The Things Network Frequency Plans - US902
* Author(s): Brent Rubell
"""
TTN_FREQS = {
    0: (0xE1, 0xF9, 0xC0),  # 903.9 MHz
    1: (0xE2, 0x06, 0x8C),  # 904.1 MHz
    2: (0xE2, 0x13, 0x20),  # 904.3 MHz
    3: (0xE2, 0x20, 0x26),  # 904.5 MHz
    4: (0xE2, 0x2C, 0xF3),  # 904.7 MHz
    5: (0xE2, 0x39, 0xC0),  # 904.9 MHz
    6: (0xE2, 0x46, 0x8C),  # 905.1 MHz
    7: (0xE2, 0x53, 0x59),
}  # 905.3 MHz
